@@ -3,8 +3,9 @@ Main interface for forecast service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.forecast import (
+    from mypy_boto3_forecast import (
         Client,
         ForecastServiceClient,
         ListDatasetGroupsPaginator,
@@ -13,7 +14,7 @@ Usage::
         ListForecastExportJobsPaginator,
         ListForecastsPaginator,
         ListPredictorsPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -26,8 +27,9 @@ Usage::
     list_forecast_export_jobs_paginator: ListForecastExportJobsPaginator = client.get_paginator("list_forecast_export_jobs")
     list_forecasts_paginator: ListForecastsPaginator = client.get_paginator("list_forecasts")
     list_predictors_paginator: ListPredictorsPaginator = client.get_paginator("list_predictors")
+    ```
 """
-from mypy_boto3_forecast.client import ForecastServiceClient as Client, ForecastServiceClient
+from mypy_boto3_forecast.client import ForecastServiceClient
 from mypy_boto3_forecast.paginator import (
     ListDatasetGroupsPaginator,
     ListDatasetImportJobsPaginator,
@@ -37,6 +39,8 @@ from mypy_boto3_forecast.paginator import (
     ListPredictorsPaginator,
 )
 
+Client = ForecastServiceClient
+
 
 __all__ = (
     "Client",
